## Instalación

```
$ npm install --save ubigeos
$ yarn add ubigeos
```

## Uso

```js
import Ubigeo, { District, Region, Province } from "ubigeos";
```

## Ejemplo 01

```javascript
import Ubigeo from "ubigeos";

const ubigeo = Ubigeo.code("250107");

console.log(`Código ubigeo: ${ubigeo.code}`);
// Código ubigeo: 250107
console.log(`Distrito: ${ubigeo.district}`);
// Distrito: Manantay
console.log(`Provincia: ${ubigeo.province}`);
// Provincia: Coronel Portillo
console.log(`Departamento: ${ubigeo.region}`);
// Departamento: Ucayali

console.log(`${ubigeo}`);
// Ucayali - Coronel Portillo - Manantay
```

## Ejemplo 02

```javascript
import { Region } from "ubigeos";

const region = Region.instance("25");

const provincies = region.getProvincies();

console.log(`Departamento: ${region.getCode()} - ${region.getName()}`);
// Departamento: 25 - Ucayali

provincies.forEach((province) => {
	console.log(`Código: ${province.getCode()}, Nombre: ${province.getName()}`);
});
//Código: 2501, Nombre: Coronel Portillo
//Código: 2502, Nombre: Atalaya
//Código: 2503, Nombre: Padre Abad
//Código: 2504, Nombre: Purús
```

## Ejemplo 03

```javascript
import { Province } from "ubigeos";

const province = Province.instance("2501");

const districts = province.getDistricts();

console.log(`Provincia: ${province.getCode()} - ${province.getName()}`);
// Provincia: 2501 - Coronel Portillo

districts.forEach((district) => {
	console.log(`Código: ${district.getCode()}, Nombre: ${district.getName()}`);
});
//Código: 250101, Nombre: Calleria
//Código: 250102, Nombre: Campoverde
//Código: 250103, Nombre: Iparia
//Código: 250104, Nombre: Masisea
//Código: 250105, Nombre: Yarinacocha
//Código: 250106, Nombre: Nueva Requena
//Código: 250107, Nombre: Manantay
```

## Ejemplo 04

```javascript
import { District } from "ubigeos";

const district = District.instance("250107");
const province = district.getProvince();
const region = province.getRegion();

console.log(`Distrito: ${district.getCode()} - ${district.getName()}`);
// Distrito: 250107 - Manantay

console.log(`Provincia: ${province.getCode()} - ${province.getName()}`);
// Provincia: 2501 - Coronel Portillo

console.log(`Departamento: ${region.getCode()} - ${region.getName()}`);
// Departamento: 25 - Ucayali
```

## Ejemplo 05

```javascript
import Ubigeo from "ubigeos";

const ubigeo = Ubigeo.location("Coronel Portillo", "Manantay");

console.log(`Código ubigeo: ${ubigeo.code}`);
// Código ubigeo: 250107
console.log(`Distrito: ${ubigeo.district}`);
// Distrito: Manantay
console.log(`Provincia: ${ubigeo.province}`);
// Provincia: Coronel Portillo
console.log(`Departamento: ${ubigeo.region}`);
// Departamento: Ucayali

console.log(`${ubigeo}`);
// Ucayali - Coronel Portillo - Manantay
```

## Ejemplo 06

```javascript
import { Location } from "ubigeos";

const location = Location.instance("Coronel Portillo", "Manantay");

console.log(`Código ubigeo: ${location.ubigeo}`);
// Código ubigeo: 250107
console.log(
	`Distrito: ${location.district.getCode()} - ${location.district.getName()}`
);
// Distrito: 250107 - Manantay
console.log(
	`Provincia: ${location.province.getCode()} - ${location.province.getName()}`
);
// Provincia: 2501 - Coronel Portillo
console.log(
	`Departamento: ${location.region.getCode()} - ${location.region.getName()}`
);
// Departamento: 25 - Ucayali
```
