"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const data_1 = require("./data");
const errors_1 = require("./errors");
const types_1 = require("./types");
class District {
    constructor(code) {
        this.setDistrictCode(code);
    }
    setDistrictCode(code) {
        this.checkDistrictCode(code);
        this._code = code;
    }
    checkDistrictCode(code) {
        const foundRegionCode = data_1.DistrictData.has(code.value());
        if (!foundRegionCode) {
            errors_1.NotFoundDistrictCode.throwBecauseOf(code.value());
        }
    }
    getName() {
        return data_1.DistrictData.get(this.getCode());
    }
    getCode() {
        return this._code.value();
    }
    getProvince() {
        return _1.Province.instance(this._code.getProvinceCode());
    }
    toString() {
        return `Provincia ${this.getCode()}, ${this.getName()}`;
    }
    static instance(code) {
        return new this(types_1.DistrictCode.of(code));
    }
}
exports.default = District;
