"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const data_1 = require("./data");
const errors_1 = require("./errors");
const utils_1 = require("./utils");
class Location {
    constructor(location) {
        this.setDistrict(location);
    }
    setDistrict(location) {
        let ubigeoCode = '';
        this.checkLocation(location);
        ubigeoCode = data_1.UbigeoData.get(utils_1.HashLib.hash(location));
        this._district = _1.District.instance(ubigeoCode);
    }
    checkLocation(location) {
        const hash = utils_1.HashLib.hash(location);
        const foundLocation = data_1.UbigeoData.has(hash);
        if (!foundLocation) {
            errors_1.NotFoundLocation.throwBecauseOf(location);
        }
    }
    static instance(province, district) {
        const newProvince = utils_1.ReplaceAccent.replace(province);
        const newDistrict = utils_1.ReplaceAccent.replace(district);
        return new this(`${newProvince.toUpperCase()} - ${newDistrict.toUpperCase()}`);
    }
    /**
     * Codigo de ubigeo
     */
    get ubigeo() {
        return this._district.getCode();
    }
    /**
     * Distrito
     */
    get district() {
        return this._district;
    }
    /**
     * Provincia
     */
    get province() {
        return this.district.getProvince();
    }
    /**
     * Departamento
     */
    get region() {
        return this.province.getRegion();
    }
}
exports.default = Location;
