"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const data_1 = require("./data");
const errors_1 = require("./errors");
const types_1 = require("./types");
class Province {
    constructor(code) {
        this.setProvinceCode(code);
    }
    setProvinceCode(code) {
        this.checkProvinceCode(code);
        this._code = code;
    }
    checkProvinceCode(code) {
        const foundRegionCode = data_1.ProvinceData.has(code.value());
        if (!foundRegionCode) {
            errors_1.NotFoundProvinceCode.throwBecauseOf(code.value());
        }
    }
    getName() {
        return data_1.ProvinceData.get(this.getCode());
    }
    getCode() {
        return this._code.value();
    }
    getRegion() {
        return _1.Region.instance(this._code.getRegionCode());
    }
    getDistricts() {
        const districts = [];
        data_1.DistrictData.forEach((value, key) => {
            if (key.substr(0, 4) === this.getCode()) {
                districts.push(_1.District.instance(key));
            }
        });
        return districts;
    }
    toString() {
        return `Provincia ${this.getCode()}, ${this.getName()}`;
    }
    static instance(code) {
        return new this(types_1.ProvinceCode.of(code));
    }
}
exports.default = Province;
