"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const data_1 = require("./data");
const errors_1 = require("./errors");
const types_1 = require("./types");
class Region {
    constructor(code) {
        this.setRegionCode(code);
    }
    setRegionCode(code) {
        this.checkRegionCode(code);
        this._code = code;
    }
    checkRegionCode(code) {
        const foundRegionCode = data_1.RegionData.has(code.value());
        if (!foundRegionCode) {
            errors_1.NotFoundRegionCode.throwBecauseOf(code.value());
        }
    }
    getName() {
        return data_1.RegionData.get(this.getCode());
    }
    getCode() {
        return this._code.value();
    }
    getProvincies() {
        const provincies = [];
        data_1.ProvinceData.forEach((value, key) => {
            if (key.substr(0, 2) === this.getCode()) {
                provincies.push(_1.Province.instance(key));
            }
        });
        return provincies;
    }
    toString() {
        return `Departamento ${this.getCode()}, ${this.getName()}`;
    }
    static instance(code) {
        return new this(types_1.RegionCode.of(code));
    }
}
exports.default = Region;
